@@ -5,7 +5,6 @@ Note: All validation errors should raise DAGSpecInitializationError, this
 allows the CLI to signal that this is a user's input error and hides the
 traceback and only displays the error message
 """
-import warnings
 import mimetypes
 from functools import partial
 from copy import copy, deepcopy
@@ -421,6 +420,7 @@ def _init_task(data, meta, project_root, lazy_import, dag):
 
     # make paths to resources absolute
     if 'params' in task_dict:
+        task_dict['params'] = _process_dotted_paths(task_dict['params'])
         task_dict['params'] = resolve_resources(task_dict['params'],
                                                 relative_to=project_root)
 
@@ -625,17 +625,17 @@ def _preprocess_grid_spec(grid_spec):
     dotted paths
     """
     if isinstance(grid_spec, Mapping):
-        return _preprocess_grid_spec_mapping(grid_spec)
+        return _process_dotted_paths(grid_spec)
     else:
         out = []
 
         for element in grid_spec:
-            out.append(_preprocess_grid_spec_mapping(element))
+            out.append(_process_dotted_paths(element))
 
         return out
 
 
-def _preprocess_grid_spec_mapping(grid_spec):
+def _process_dotted_paths(grid_spec):
     """
     Preprocess a grid (dictionary) to expand values if it contains
     dotted paths
@@ -644,17 +644,13 @@ def _preprocess_grid_spec_mapping(grid_spec):
 
     for key, value in grid_spec.items():
         try:
-            dp = dotted_path.DottedPath(value, allow_return_none=False)
-        # raised if not a string
-        except (TypeError, ValueError):
-            dp = None
-        # there are other exceptions, but we only display a warning since
-        # it might be that the user just wants to pass that string as-is
-        # and it's not intended to be a dotted path
-        except Exception as e:
-            msg = ('You parameter looks like a dotted path '
-                   f'but it failed to load: {str(e)}')
-            warnings.warn(msg, category=dotted_path.DottedPathWarning)
+            dp = dotted_path.DottedPath(value,
+                                        allow_return_none=False,
+                                        strict=True)
+        # TypeError: not a string or dictionary
+        # ValueError: not the module::function format
+        # KeyError: dictionary with missing dotted_path key
+        except (TypeError, ValueError, KeyError):
             dp = None
 
         if dp:
